# Example CUJ: Retrain (& Optionally Modify) a Trained Model

This CUJ is split into two components:

1. `train.py`: Trains a job in the SDK.
1. `retrain.py`: Loads the trained job from (1), optionally modifies the model
   plan, and re-trains the job.
